@@ -3,6 +3,8 @@
 
 import argparse
 import logging
+import os.path
+import pathlib
 import sys
 
 from ._version import version as __version__
@@ -31,25 +33,52 @@ def main() -> None:
         action="store_true",
         help="force fetch the latest TLD definitions",
     )
+    parser.add_argument(
+        "--suffix_list_url",
+        action="append",
+        required=False,
+        help="use an alternate URL or local file for TLD definitions",
+    )
     parser.add_argument(
         "-c", "--cache_dir", help="use an alternate TLD definition caching folder"
     )
     parser.add_argument(
         "-p",
+        "--include_psl_private_domains",
         "--private_domains",
         default=False,
         action="store_true",
         help="Include private domains",
     )
+    parser.add_argument(
+        "--no_fallback_to_snapshot",
+        default=True,
+        action="store_false",
+        dest="fallback_to_snapshot",
+        help="Don't fall back to the package's snapshot of the suffix list",
+    )
 
     args = parser.parse_args()
 
     obj_kwargs = {
-        "include_psl_private_domains": args.private_domains,
+        "include_psl_private_domains": args.include_psl_private_domains,
+        "fallback_to_snapshot": args.fallback_to_snapshot,
     }
+
     if args.cache_dir:
         obj_kwargs["cache_dir"] = args.cache_dir
 
+    if args.suffix_list_url is not None:
+        suffix_list_urls = []
+        for source in args.suffix_list_url:
+            if os.path.isfile(source):
+                as_path_uri = pathlib.Path(os.path.abspath(source)).as_uri()
+                suffix_list_urls.append(as_path_uri)
+            else:
+                suffix_list_urls.append(source)
+
+        obj_kwargs["suffix_list_urls"] = suffix_list_urls
+
     tld_extract = TLDExtract(**obj_kwargs)
 
     if args.update:
@@ -57,7 +86,6 @@ def main() -> None:
     elif not args.input:
         parser.print_usage()
         sys.exit(1)
-        return
 
     for i in args.input:
         print(" ".join(tld_extract(i)))
